// gshhs_info.h
#ifndef _gshhs_info_H_
#define _gshhs_info_H_
#include "win_map.h"    // for MAPVW
#include "gshhs_list.h"

typedef struct tagFGINFO {
   LE    apts, rwys, navs;       // aitports, runways, and navaids within bounds
   int   apt_cnt, rwy_cnt; // counts airports and runways within bounds
   int   add_all;    // add runways and taxiways
   int   add_circle;   // add VOR/NDB circles
   int   add_ident;     // add VOR/NDB ident
   int   add_fill;      // fill rect airport bounds
   int   add_name;      // add airport NAME text
   int   add_id;      // add airport ID text (ICAO)
   int   apt_count;     // FG apt.dat count, if any
   int   nav_count;     // NAV data load, if any
   char  aptdat[MAX_PATH];  // input FILE NAME
   char  navdat[MAX_PATH]; // navaid input file
}FGINFO, * PFGINFO;

typedef struct tagGSRANGE {
   double e, n, s, w;   // boundary, in degrees
   int TLilat, TLilon, BRilat, BRilon; // top/left and bottom/right boundary, in pixels
   int BLilat, BLilon, TRilat, TRilon; // bottom/left and top/right - different if NOT mercator
   double area;   // km^2
   double dwid, dhgt;
   double centlat, centlon, range;  // User CENTER lat,lon,range (in Kilometers)
   double centerlat, centerlon;
   double degspplat, degspplon;
   int autoscale;
   size_t bmpsize;      // if autoscale, attempted MINIMUM BMP size
   long scale, height, width;
   long ailat, ailon;   // offsets, to fix pixel location
   long ptcount;        // bits ADDED to block
   double mxlat, mnlat, mxlon, mnlon;  // point limits, in degrees
   long maxilat, maxilon, minilat, minilon;  // point limits, in pixels
   PBYTE pblock;
}GSRANGE, * PGSRANGE;

typedef struct tagBMPSTUFF {
   int   bms_width, bms_height, bms_rowwid;
   double vscale, hscale;
   PBYTE pbits;
}BMPSTUFF, * PBMPSTUFF;

typedef struct tagBMPINFO {
   BOOL joinGSHHS;      // join GSHHS points of SAME number
   BOOL addgrid;        // add lat/lon grid
   BOOL addborder;      // add a border around BMP
   BOOL doculling;      // cull to potentially reduce BMP size (Def=ON)
   BOOL blockwrite;     // write additional BLOCK bitmap (Def=OFF)
   BOOL addinfo;        // add the FILE INFO (Def=On)
   BOOL addscale;       // add a scale legend to the bottom left (Def=On)
   int  nBPP;           // bits per pixel bitmap
   int  mercator;       // use mercator projection
   GSRANGE  range;      // ranges of bitmap
   BMPSTUFF bmpstuff;   // various items fro writing the BITAMP
   int  execute;        // default = ON, using imdisplay ...
   char bmpname[MAX_PATH];  // output FILE NAME
   char exename[MAX_PATH]; // executable to load BITMAP

}BMPINFO, * PBMPINFO;

typedef struct tagGSINFO {
   //char fn[MAX_PATH];   // file being process
   double max_lon, max_lat;
   double min_lon, min_lat;
   ULONGLONG hdrcnt, ptcnt;   // set during Integrity_Check(pgsi)
   double n_max, n_min;
   double e_max, e_min;
   double s_max, s_min;
   double w_max, w_min;
   double h_max, h_min;
   int   listinfoa, listinfoh, listinfop;
   int   verbosity;
   FGINFO   fgdata;  // FG stuff
   BMPINFO  bmpinfo;
   MAPVW mv;   // WIN32 mapped file buffer
   int   overwrite;  // set for FIRST, cleared for others for GSHHS points
   BYTE  def_bmc; // set block to this
   BYTE  txt_bmc; // when putting TEXT
   BYTE  ll_bmc;  // lat/lon grid color
   BYTE  bdr_bmc; // border color

}GSINFO, * PGSINFO;

extern void Init_GSINFO( PGSINFO pgsi );
extern void Add_2_GSLimits( double n, double s, double e, double w, PGSINFO pgsi );
extern void Add_2_GSINFO( double lat, double lon, PGSINFO pgsi );
extern BOOL In_GSHHS_Range( double lat, double lon, PGSINFO pgsi );

#define  VERB1(a) ( a->verbosity >= 1 )
#define  VERB2(a) ( a->verbosity >= 2 )
#define  VERB3(a) ( a->verbosity >= 3 )
#define  VERB4(a) ( a->verbosity >= 4 )
#define  VERB5(a) ( a->verbosity >= 5 )
#define  VERB8(a) ( a->verbosity >= 8 )
#define  VERB9(a) ( a->verbosity >= 9 )

#endif // _gshhs_info_H_
// eof - gshhs_info.h
